from django.apps import AppConfig


class JutilConfig(AppConfig):
    name = "jutil"
